pub struct DatasetQuery<'a> { /* private fields */ }Expand description
Read-only query interface over a binary LXDB dataset.
The query borrows the dataset and does not allocate an intermediate graph.
Implementations
Sourceimpl<'a> DatasetQuery<'a>
impl<'a> DatasetQuery<'a>
pub const fn new(dataset: &'a BinaryDataset) -> Self
pub const fn dataset(&self) -> &'a BinaryDataset
Sourcepub fn token_by_text(
&self,
text: &str,
) -> Result<Option<BinaryToken<'a>>, EngineError>
pub fn token_by_text( &self, text: &str, ) -> Result<Option<BinaryToken<'a>>, EngineError>
Finds the first token whose text exactly matches text.
This performs a linear scan over the token records.
pub fn token_by_id( &self, token_id: TokenId, ) -> Result<Option<BinaryToken<'a>>, EngineError>
pub fn outgoing( &self, token_id: TokenId, ) -> Result<RelationRecordIter<'a>, EngineError>
Sourcepub fn resolved_outgoing(
&self,
token_id: TokenId,
) -> Result<BinaryRelationIter<'a>, EngineError>
pub fn resolved_outgoing( &self, token_id: TokenId, ) -> Result<BinaryRelationIter<'a>, EngineError>
Resolves all outgoing relations for a token.
Finds a token by text and resolves its outgoing relations.
Ok(None) means that no token exists with the provided text.